@@ -1,6 +1,6 @@
 ;;; denote-journal.el --- Convenience functions for daily journaling with Denote -*- lexical-binding: t; -*-
 
-;; Copyright (C) 2023-2025  Free Software Foundation, Inc.
+;; Copyright (C) 2023-2026  Free Software Foundation, Inc.
 
 ;; Author: Protesilaos Stavrou <info@protesilaos.com>
 ;; Maintainer: Protesilaos Stavrou <info@protesilaos.com>
@@ -336,7 +336,10 @@ Perform the operation relative to the variable `denote-journal-directory'."
          (denote-directory default-directory)
          (relative-files (mapcar #'denote-get-file-name-relative-to-denote-directory files))
          (file (if (> (length files) 1)
-                   (completing-read "Select journal entry: " (denote--completion-table 'file relative-files) nil t)
+                   (completing-read
+                    "Select journal entry: "
+                    (apply 'denote-get-completion-table relative-files denote-file-prompt-extra-metadata)
+                    nil t)
                  (car relative-files))))
     (concat denote-directory file)))
 
